========================
Pytest Django Migrations
========================

 - version number: 0.4.0 
 - author: Kit La Touche

Overview
--------

Test Django migrations through Pytest.

Installation / Usage
--------------------

To install use pip::

    $ pip install pytedjmi


Or clone the repo::

    $ git clone https://github.com/wlonk/pytest-django-migrations.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD
